from datetime import time, timedelta
import itertools

import pytest
from model_bakery import baker

from aircox.models import Diffusion


@pytest.fixture
def stations():
    return baker.make("aircox.station", quantity=2)


@pytest.fixture
def programs(stations):
    return list(
        itertools.chain(
            *(
                baker.make("aircox.program", quantity=3, station=station)
                for station in stations
            )
        )
    )


@pytest.fixture
def sched_initials(programs):
    # use concrete class
    return [
        baker.make("aircox.schedule", program=program, time=time(16, 00))
        for program in programs
    ]


@pytest.fixture
def sched_reruns(initials):
    # use concrete class
    return [
        baker.make(
            "aircox.schedule",
            initial=initial,
            date=initial.date,
            time=(initial.start + timedelta(hours=1)).time(),
        )
        for initial in initials
    ]


@pytest.fixture
def schedules(sched_initials, sched_reruns):
    return sched_initials + sched_reruns


@pytest.fixture
def episodes(programs):
    items = []
    for program in programs:
        items += [
            baker.make("aircox.episode", parent=program, type=type)
            for type, _ in Diffusion.TYPE_CHOICES
        ]
    return items
